@@ -55,6 +55,8 @@ JOB_FLOW_OVERRIDES = {
 
 DEFAULT_ARGS = {
     "execution_timeout": timedelta(hours=EXECUTION_TIMEOUT),
+    "retries": int(os.getenv("DEFAULT_TASK_RETRIES", 2)),
+    "retry_delay": timedelta(seconds=int(os.getenv("DEFAULT_RETRY_DELAY_SECONDS", 60))),
 }
 
 
