@@ -30,6 +30,8 @@ EXECUTION_TIMEOUT = int(os.getenv("EXECUTION_TIMEOUT", 6))
 
 default_args = {
     "execution_timeout": timedelta(hours=EXECUTION_TIMEOUT),
+    "retries": int(os.getenv("DEFAULT_TASK_RETRIES", 2)),
+    "retry_delay": timedelta(seconds=int(os.getenv("DEFAULT_RETRY_DELAY_SECONDS", 60))),
 }
 
 
@@ -137,8 +139,8 @@ def delete_redshift_cluster_snapshot_callable() -> None:
             logging.exception("Error when deleting the cluster")
             raise
 
-    # Introduce sleep to wait for the cluster to be available back after snapshot activity before proceeding on to the
-    # downstream task.
+    # Introduce sleep to wait for the cluster to be available back after snapshot activity before proceeding on to
+    # the downstream task.
     while get_cluster_status() != "available":
         logging.info("Waiting for cluster to be available. Sleeping for 30 seconds.")
         time.sleep(30)
