@@ -1,5 +1,4 @@
 import asyncio
-import logging
 from typing import Any, AsyncIterator, Dict, Optional, Tuple
 
 from airflow.triggers.base import BaseTrigger, TriggerEvent
@@ -7,8 +6,6 @@ from google.cloud.dataproc_v1.types import JobStatus
 
 from astronomer.providers.google.cloud.hooks.dataproc import DataprocHookAsync
 
-log = logging.getLogger(__name__)
-
 
 class DataProcSubmitTrigger(BaseTrigger):
     """
@@ -31,9 +28,8 @@ class DataProcSubmitTrigger(BaseTrigger):
         project_id: Optional[str] = None,
         gcp_conn_id: str = "google_cloud_default",
         polling_interval: float = 5.0,
-        **kwargs: Any,
     ) -> None:
-        super().__init__(**kwargs)
+        super().__init__()
         self.project_id = project_id
         self.gcp_conn_id = gcp_conn_id
         self.dataproc_job_id = dataproc_job_id
@@ -73,15 +69,19 @@ class DataProcSubmitTrigger(BaseTrigger):
         job = await hook.get_job(job_id=self.dataproc_job_id, region=self.region, project_id=self.project_id)
         state = job.status.state
         if state == JobStatus.State.ERROR:
-            return {"status": "error", "message": "Job Failed"}
+            return {"status": "error", "message": "Job Failed", "job_id": self.dataproc_job_id}
         elif state in {
             JobStatus.State.CANCELLED,
             JobStatus.State.CANCEL_PENDING,
             JobStatus.State.CANCEL_STARTED,
         }:
-            return {"status": "error", "message": "Job got cancelled"}
+            return {"status": "error", "message": "Job got cancelled", "job_id": self.dataproc_job_id}
         elif JobStatus.State.DONE == state:
-            return {"status": "success", "message": "Job completed successfully"}
+            return {
+                "status": "success",
+                "message": "Job completed successfully",
+                "job_id": self.dataproc_job_id,
+            }
         elif JobStatus.State.ATTEMPT_FAILURE == state:
-            return {"status": "pending", "message": "Job is in pending state"}
-        return {"status": "pending", "message": "Job is in pending state"}
+            return {"status": "pending", "message": "Job is in pending state", "job_id": self.dataproc_job_id}
+        return {"status": "pending", "message": "Job is in pending state", "job_id": self.dataproc_job_id}
