@@ -1,5 +1,4 @@
 import asyncio
-import logging
 import os
 from datetime import datetime
 from typing import Any, AsyncIterator, Dict, List, Optional, Set, Tuple
@@ -10,8 +9,6 @@ from airflow.utils import timezone
 
 from astronomer.providers.google.cloud.hooks.gcs import GCSHookAsync
 
-log = logging.getLogger(__name__)
-
 
 class GCSBlobTrigger(BaseTrigger):
     """
