@@ -20,6 +20,8 @@ default_args = {
     "azure_data_factory_conn_id": "azure_data_factory_default",
     "factory_name": "ADFProvidersTeamDataFactoryTest",  # This can also be specified in the ADF connection.
     "resource_group_name": "team_provider_resource_group_test_1",  # This can also be specified in the ADF connection.
+    "retries": int(os.getenv("DEFAULT_TASK_RETRIES", 2)),
+    "retry_delay": timedelta(seconds=int(os.getenv("DEFAULT_RETRY_DELAY_SECONDS", 60))),
 }
 
 CLIENT_ID = os.getenv("CLIENT_ID", "")
@@ -183,17 +185,17 @@ with DAG(
     # [END howto_create_resource_group]
 
     # [START howto_operator_adf_run_pipeline]
-    run_pipeline_no_wait = AzureDataFactoryRunPipelineOperatorAsync(
-        task_id="run_pipeline_no_wait",
+    run_pipeline_wait = AzureDataFactoryRunPipelineOperatorAsync(
+        task_id="run_pipeline_wait",
         pipeline_name=PIPELINE_NAME,
-        wait_for_termination=False,
     )
     # [END howto_operator_adf_run_pipeline]
 
     # [START howto_operator_adf_run_pipeline]
-    run_pipeline_wait = AzureDataFactoryRunPipelineOperatorAsync(
-        task_id="run_pipeline_wait",
+    run_pipeline_no_wait = AzureDataFactoryRunPipelineOperatorAsync(
+        task_id="run_pipeline_no_wait",
         pipeline_name=PIPELINE_NAME,
+        wait_for_termination=False,
     )
     # [END howto_operator_adf_run_pipeline]
 
@@ -212,8 +214,8 @@ with DAG(
 
     (
         create_azure_data_factory_storage_pipeline
-        >> run_pipeline_no_wait
         >> run_pipeline_wait
+        >> run_pipeline_no_wait
         >> pipeline_run_sensor_async
         >> remove_azure_data_factory_storage_pipeline
     )
