@@ -27,6 +27,8 @@ SNOWFLAKE_SLACK_MESSAGE = (
 default_args = {
     "execution_timeout": timedelta(hours=EXECUTION_TIMEOUT),
     "snowflake_conn_id": SNOWFLAKE_CONN_ID,
+    "retries": int(os.getenv("DEFAULT_TASK_RETRIES", 2)),
+    "retry_delay": timedelta(seconds=int(os.getenv("DEFAULT_RETRY_DELAY_SECONDS", 60))),
 }
 
 with DAG(
